@@ -97,9 +97,9 @@ class MySQLPipeline(metaclass=SingletonType):
                         PRIMARY KEY (`cd_id`)
                         )ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4;'''
                 # --创建update触发器
-                sql_trigger = f'''CREATE TRIGGER `trig_{table}_updatetime` 
-                                  BEFORE UPDATE ON `{table}` FOR EACH ROW
-                                  SET NEW.`cd_updatetime` = NOW();
+                sql_trigger = f'''CREATE TRIGGER trig_{table}_updatetime 
+                                  BEFORE UPDATE ON {table} FOR EACH ROW
+                                  SET NEW.cd_updatetime = NOW();
                                   FLUSH'''
                 try:
                     # print(sql_table)
